/* messagewin.c -- PLACEHOLDER */

#include "messagewin.h"


void
popup_meswin_dialog(void)
{
	/* PORTME */
}

bool is_meswin_open(void)
{
	/* PORTME */
}

void
real_update_meswin_dialog(void)
{
	/* PORTME */
}

void
real_clear_notify_window(void)
{
	/* PORTME */
}

void
real_add_notify_window(struct packet_generic_message *packet)
{
	/* PORTME */
}
